@@ -61,7 +61,9 @@ def state():
     for host in ssh_config.hosts():
         if "*" in host:
             continue
-        ssh_hosts.append(host)
+        hosts = host.split(" ")
+        for hostname in hosts:
+            ssh_hosts.append(hostname)
 
     forward_sessions.refresh_state()
     time.sleep(0.5)
