@@ -53,7 +53,10 @@ def ac_hosts(incomplete):
     c = read_ssh_config(expanduser("~/.ssh/config"))
     for host in c.hosts():
         if "*" not in host and host.startswith(incomplete):
-            result.append(host)
+            hosts = host.split(" ")
+            for hostname in hosts:
+                result.append(hostname)
+
     return result
 
 
@@ -64,6 +67,9 @@ def sc_hosts(ctx, param, incomplete):
     c = read_ssh_config(expanduser("~/.ssh/config"))
     for host in c.hosts():
         if "*" not in host and host.startswith(incomplete):
-            item = CompletionItem(host)
-            result.append(item)
+            hosts = host.split(" ")
+            for hostname in hosts:
+                item = CompletionItem(hostname)
+                result.append(item)
+
     return result
